@@ -72,12 +72,14 @@ def test_search_fast(test_db, test_vuln_data):
     all_data = db.list_all(table)
     assert all_data
     search_list = [
-        d["details"]["package"] + "|" + d["details"]["max_affected_version_including"]
+        {
+            "name": d["details"]["package"],
+            "version": d["details"]["max_affected_version_including"],
+        }
         for d in all_data
     ]
-    res = db.pkg_bulk_search(test_db, search_list)
-    assert len(res) > len(set(search_list))
-    assert res[0].to_dict()["package_issue"]
+    res = db.bulk_index_search(search_list)
+    assert len(res)
 
 
 def test_gha_create(test_db, test_gha_data):
@@ -165,7 +167,7 @@ def test_index_search(test_db, test_vuln_data):
     assert len(res)
     for r in res:
         name_ver = r.split("|")
-        fullres = db.index_search(name_ver[0], name_ver[1])
+        fullres = db.index_search(name_ver[1], name_ver[2])
         assert fullres
 
 
@@ -192,5 +194,5 @@ def test_vendor_index_search(test_db, test_vuln_data):
     assert len(res)
     for r in res:
         name_ver = r.split("|")
-        fullres = db.index_search(name_ver[1], name_ver[2])
+        fullres = db.index_search(name_ver[2], name_ver[3])
         assert fullres
